diff --git a/Gruntfile.js b/Gruntfile.js
index 4c64d59..175b509 100644
--- a/Gruntfile.js
+++ b/Gruntfile.js
@@ -108,65 +108,6 @@ module.exports = function( grunt ) {
debounceDelay: 500
}
}
- },
- 'sftp-deploy': {
- css: {
- auth: {
- host: 'server.territorial.ca',
- port: 22,
- authKey: 'key1'
- },
- cache: 'sftpCache.json',
- src: '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/assets/css/',
- dest: '/home/ascribe/public_html/wp-content/themes/ascribe/assets/css',
- exclusions: ['/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/node_modules',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/release',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/vendor',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/.git',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/.idea',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/**/.DS_Store'],
- serverSep: '/',
- concurrency: 4,
- progress: true
- },
- js: {
- auth: {
- host: 'server.territorial.ca',
- port: 22,
- authKey: 'key1'
- },
- cache: 'sftpCache.json',
- src: '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/assets/js/',
- dest: '/home/ascribe/public_html/wp-content/themes/ascribe/assets/js',
- exclusions: ['/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/node_modules',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/release',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/vendor',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/.git',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/.idea',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/**/.DS_Store'],
- serverSep: '/',
- concurrency: 4,
- progress: true
- },
- controller: {
- auth: {
- host: 'server.territorial.ca',
- port: 22,
- authKey: 'key1'
- },
- cache: 'sftpCache.json',
- src: '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/controller/',
- dest: '/home/ascribe/public_html/wp-content/themes/ascribe/controller/',
- exclusions: ['/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/node_modules',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/release',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/vendor',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/.git',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/.idea',
- '/Users/sarahetter/Dropbox/_shared/sarahetter/ascribe/**/.DS_Store'],
- serverSep: '/',
- concurrency: 4,
- progress: true
- }
}
} );
@@ -175,13 +116,13 @@ module.exports = function( grunt ) {
// Register tasks
- grunt.registerTask( 'css', ['less', 'postcss', 'cssmin', 'sftp-deploy:css'] );
+ grunt.registerTask( 'css', ['less', 'postcss', 'cssmin'] );
- grunt.registerTask( 'js', ['jshint', 'concat', 'uglify', 'sftp-deploy:js'] );
+ //grunt.registerTask( 'js', ['jshint', 'concat', 'uglify'] );
- grunt.registerTask( 'controller', ['sftp-deploy:controller'] );
+ grunt.registerTask( 'controller', [] );
- grunt.registerTask( 'default', ['css', 'js', 'controller'] );
+ grunt.registerTask( 'default', ['css', 'controller'] );
grunt.util.linefeed = '\n';
};
\ No newline at end of file
diff --git a/assets/css/ascribe.css b/assets/css/ascribe.css
index 2c6e470..98fc254 100644
--- a/assets/css/ascribe.css
+++ b/assets/css/ascribe.css
@@ -1157,6 +1157,69 @@ header + .chevron-divider {
line-height: 30px;
color: #67c4da;
}
+.page-template-template-tour header nav:hover {
+ cursor: pointer;
+}
+.page-template-template-tour header nav:hover a {
+ color: #d8127d;
+}
+.page-template-template-tour header nav:hover ul:before,
+.page-template-template-tour header nav:hover ul li a:after {
+ color: #d8127d;
+}
+.page-template-template-tour header nav ul {
+ display: -webkit-flex;
+ display: -ms-flexbox;
+ display: flex;
+ -webkit-flex-wrap: wrap;
+ -ms-flex-wrap: wrap;
+ flex-wrap: wrap;
+ padding: 0 35px;
+ position: relative;
+ -webkit-flex-direction: column;
+}
+.page-template-template-tour header nav ul:hover {
+ cursor: pointer;
+}
+.page-template-template-tour header nav ul.active li {
+ display: -webkit-flex;
+ display: -ms-flexbox;
+ display: flex;
+}
+.page-template-template-tour header nav ul li {
+ -webkit-flex-grow: 1;
+ -ms-flex-positive: 1;
+ flex-grow: 1;
+ -webkit-order: 2;
+ -ms-flex-order: 2;
+ order: 2;
+ display: none;
+}
+.page-template-template-tour header nav ul li.current-menu-item {
+ -webkit-order: 1;
+ -ms-flex-order: 1;
+ order: 1;
+ display: -webkit-flex;
+ display: -ms-flexbox;
+ display: flex;
+}
+.page-template-template-tour header nav ul li.current-menu-item a {
+ position: relative;
+}
+.page-template-template-tour header nav ul li.current-menu-item a:after {
+ content: '▼';
+ display: inline-block;
+ position: absolute;
+ top: 3px;
+ right: -34px;
+}
+.page-template-template-tour header nav ul:before {
+ content: 'for ';
+ display: inline-block;
+ position: absolute;
+ top: 0;
+ left: 0;
+}
.page-template-template-tour header ul {
list-style: none;
}
@@ -1509,6 +1572,32 @@ header + .chevron-divider {
width: 100%;
}
}
+.feature-circles .surround-circle {
+ display: inline-block;
+ vertical-align: top;
+ padding-right: 30px;
+ font-size: 15px;
+ width: 33.33333333%;
+ text-align: center;
+ position: relative;
+ width: 30%;
+ padding: 80px 50px 170px;
+}
+@media screen and (max-width: 570px) {
+ .feature-circles .surround-circle {
+ width: 100%;
+ }
+}
+.feature-circles .surround-circle:before {
+ top: 0;
+ left: 5%;
+ width: 90%;
+ background: transparent url('../img/circle.png') no-repeat center top;
+ background-size: 100%;
+ height: 100%;
+ content: '';
+ position: absolute;
+}
.feature-circles img {
width: 105px;
display: block;
@@ -2235,6 +2324,38 @@ header + .chevron-divider {
width: 100%;
}
}
+.content-boxed {
+ background-color: #fbfbfb;
+}
+.content-boxed .centered-content-padding {
+ background-color: #fbfbfb;
+}
+.content-boxed .centered-content > div {
+ border: 1px solid #d8127d;
+ background-color: #ffffff;
+ padding: 30px;
+}
+.content-boxed .centered-content > div > ul {
+ margin: 30px;
+ overflow: hidden;
+}
+.content-boxed .centered-content > div > ul > li {
+ float: left;
+ clear: left;
+ width: 100%;
+ text-align: right;
+}
+.content-boxed .centered-content > div > ul ul {
+ width: 70%;
+ float: right;
+ text-align: left;
+}
+.content-boxed .centered-content p {
+ max-width: 640px;
+}
+.content-boxed .centered-content img {
+ margin: 30px 0;
+}
.blog .column-container {
width: calc(100% + 70px);
}
diff --git a/assets/css/ascribe.min.css b/assets/css/ascribe.min.css
index 825309c..b953178 100644
--- a/assets/css/ascribe.min.css
+++ b/assets/css/ascribe.min.css
@@ -1 +1 @@
-/*! normalize.css v3.0.1 | MIT License | git.io/normalize */legend,td,th{padding:0}.wrapper,header{overflow:hidden}.wrapper,sub,sup{position:relative}.old-new table,table{border-collapse:collapse}.careers ul,.page-template-template-tour header ul,footer ul{list-style:none}html{-ms-text-size-adjust:100%;-webkit-text-size-adjust:100%}body{margin:0}article,aside,details,figcaption,figure,footer,header,hgroup,main,nav,section,summary{display:block}audio,canvas,progress,video{display:inline-block;vertical-align:baseline}audio:not([controls]){display:none;height:0}[hidden],template{display:none}a:active,a:hover{outline:0}abbr[title]{border-bottom:1px dotted}b,optgroup,strong{font-weight:700}dfn{font-style:italic}h1{margin:.67em 0}mark{background:#ff0;color:#000}small{font-size:80%}sub,sup{font-size:75%;line-height:0;vertical-align:baseline}sup{top:-.5em}sub{bottom:-.25em}figure{margin:1em 40px}pre,textarea{overflow:auto}code,kbd,pre,samp{font-family:monospace,monospace;font-size:1em}button,input,optgroup,select,textarea{color:inherit;font:inherit;margin:0}button{overflow:visible}button,select{text-transform:none}button,html input[type=button],input[type=reset],input[type=submit]{-webkit-appearance:button;cursor:pointer}button[disabled],html input[disabled]{cursor:default}button::-moz-focus-inner,input::-moz-focus-inner{border:0;padding:0}input{line-height:normal}input[type=checkbox],input[type=radio]{box-sizing:border-box;padding:0}input[type=number]::-webkit-inner-spin-button,input[type=number]::-webkit-outer-spin-button{height:auto}input[type=search]{-webkit-appearance:textfield;box-sizing:content-box}input[type=search]::-webkit-search-cancel-button,input[type=search]::-webkit-search-decoration{-webkit-appearance:none}fieldset{border:1px solid silver;margin:0 2px;padding:.35em .625em .75em}legend{border:0}table{border-spacing:0}@media print{blockquote,img,pre,tr{page-break-inside:avoid}*{background:0 0!important;color:#000!important;text-shadow:none!important;-webkit-filter:none!important;filter:none!important;-ms-filter:none!important}a,a:visited{color:#444!important;text-decoration:underline}a[href]:after{content:" (" attr(href) ")"}abbr[title]:after{content:" (" attr(title) ")"}.ir a:after,a[href^="#"]:after,a[href^="javascript:"]:after{content:""}blockquote,pre{border:1px solid #999}thead{display:table-header-group}@page{margin:.5cm}h2,h3,p{orphans:3;widows:3}h2,h3{page-break-after:avoid}}.button,a{text-decoration:none}body,html{height:100%;color:#121417;font-size:15px;line-height:19px;font-smoothing:antialiased;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;background-color:#fff}body.page-template-template-companyblue,html.page-template-template-companyblue{color:#121417;font-size:18px;line-height:22px}a{background:0 0;color:#67c4da}a:hover{color:#d8127d}.app-links,.app-links a,.blog-features h1,.blog-features h2,.blog-sidebar .sidebar-blog-features,.blue-box,.blueBoxCopy,.button.small,.careers a,.contact .contact-point,.contact .form,.contact .required-info,.contact .wpcf7-not-valid-tip,.contact input[type=submit].small,.contact label,.copyText,.copyTextMedium,.copyTextSmall,.faq,.feature-circles .description,.feature-circles h1,.featureBlogDesc,.featureBlogTitle,.featureCircleH1,.fontLight,.footerText,.galleries-marketplaces h1,.galleriesPressTitle,.h1,.h3,.h5,.heroText,.old-new h1,.old-new td,.old-new th,.oldWayNewWayTH,.page-template-template-tour header h1,.page-template-template-tour header nav,.past-events .event,.past-events .event time,.press-articles,.product-overview h1,.product-overview p,.sectionHeader,.signInUpText,.single-post .entry,.subsectionHeader,.subtemplate h1,.team,.team h2,.tourNavText,.upcoming-events .event,.upcoming-events .event time,.values .value,article.post .post-categories,article.post h2,body,body.page-template-template-companyblue,footer,footer a,h1,h3,h5,html,html.page-template-template-companyblue{font-family:canada-type-gibson,sans-serif;font-weight:200}.archive header .app-links a:hover,.archive header+nav a,.blog header .app-links a:hover,.blog header+nav a,.blog-sidebar .sidebar-blog-features h1,.blue-box h1,.blueBoxTitle,.button,.case-studies .description,.caseStudyText,.contact .contact-point h1,.contact input[type=submit],.faq .featured-faqs dt,.faq .regular-faqs dt,.fontRegular,.h2,.h4,.h6,.past-events .event h1,.press-articles .press-article h1,.single-post header .app-links a:hover,.single-post header+nav a,.team h1,.teamName,.upcoming-events .event h1,.values .value h1,footer a:hover,h2,h4,h6{font-family:canada-type-gibson,sans-serif;font-weight:400}.sectionHeader{font-size:34px;color:#67c4da;line-height:1.2;margin:35px 0;text-align:center}@media screen and (max-width:768px){.sectionHeader{font-size:30px}}.subsectionHeader{font-size:31px;color:#000;line-height:37px;text-align:center}.h1,.h2,.h3,h1,h2,h3{color:#d8127d}.h1,.h2,.h3,.h4,.h5,h1,h2,h3,h4,h5{line-height:1.2}.h1,h1{font-size:36px}.h2,h2{font-size:26px}.h3,h3{font-size:27px}.h4,.h5,h4,h5{font-size:26px;color:#000}.h6,h6{color:#d8127d;font-size:15px;line-height:19px}.copyText{color:#121417;font-size:18px;line-height:22px}.copyTextMedium{color:#121417;font-size:17px;line-height:21px}.copyTextSmall{color:#121417;font-size:15px;line-height:19px}.heroText{font-size:37px;color:#fff;line-height:44px}.tourNavText{font-size:25px;line-height:30px;color:#67c4da}.signInUpText{font-size:17px;line-height:20px;color:#fff;text-transform:uppercase}.featureCircleH1{font-size:20px;color:#d8127d;letter-spacing:1.11px;line-height:24px;margin-bottom:22px}.caseStudyText{font-size:23px;color:#fff;line-height:28px}.oldWayNewWayTH{font-size:24px;color:#d8127d;line-height:29px}.blueBoxCopy,.blueBoxTitle{font-size:43px;color:#fff;line-height:52px}.blueBoxTitle{text-align:center}.galleriesPressTitle{font-size:30px;color:#000;line-height:36px;margin-bottom:50px}.featureBlogDesc{font-size:13px;color:#67c4da;line-height:22.79px}.featureBlogTitle{font-size:17px;color:#595959;line-height:22.79px;text-transform:uppercase}.teamName{color:#000;font-size:19px}.footerText{font-size:14px;color:#fff;line-height:25px}.subfooterText{color:#1e1e1e;font-size:13px;line-height:14px}.button{display:inline-block;padding:25px 40px;border:1px solid;font-size:22px;line-height:26px;min-width:265px;text-align:center}.button.blue,.button.blue-overPic,.button.white-blue{border-color:#67c4da}.button.blue{color:#fff;background-color:#67c4da}.button.blue:hover{background-color:rgba(103,196,218,.5)}.button.blue-overPic{color:#fff;background-color:#67c4da}.button.blue-overPic:hover,.button.white-blue{color:#67c4da;background-color:#fff}.button.white-blue:hover{background-color:rgba(103,196,218,.5);color:#fff}.button.small{padding:5px 15px;font-size:14px;color:#fff;background-color:transparent;border-color:#fff;min-width:auto}.button.small:hover{background-color:rgba(255,255,255,.4);border-color:rgba(255,255,255,.4);color:#fff}.chevron-divider{background-image:url(../../images/svg/ascribe-chevron.svg);background-position:bottom;width:100%;background-size:100%;height:150px}@media screen and (max-width:768px){.chevron-divider{background-size:120%}}.social-icon{width:21px;height:21px;padding:1px;fill:#fff;background-color:#b8b8b8;border-radius:5px}.social-icon:hover{background-color:rgba(184,184,184,.4)}hr{box-sizing:content-box;border:0;height:2px;background:#979797;margin:40px 0}.archive header,.blog header,.blueGradient,.page-template-template-companyblue .subtemplate:first-of-type,.single-post header{background:url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiA/Pgo8c3ZnIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdmlld0JveD0iMCAwIDEgMSIgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSI+CiAgPGxpbmVhckdyYWRpZW50IGlkPSJncmFkLXVjZ2ctZ2VuZXJhdGVkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgeDE9IjAlIiB5MT0iMCUiIHgyPSIwJSIgeTI9IjEwMCUiPgogICAgPHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iIzUxOWNhZCIgc3RvcC1vcGFjaXR5PSIxIi8+CiAgICA8c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29sb3I9IiM2N2M0ZGEiIHN0b3Atb3BhY2l0eT0iMSIvPgogIDwvbGluZWFyR3JhZGllbnQ+CiAgPHJlY3QgeD0iMCIgeT0iMCIgd2lkdGg9IjEiIGhlaWdodD0iMSIgZmlsbD0idXJsKCNncmFkLXVjZ2ctZ2VuZXJhdGVkKSIgLz4KPC9zdmc+);background:linear-gradient(to bottom,#519cad 0,#67c4da 100%);filter:progid:DXImageTransform.Microsoft.gradient(startColorstr='#519cad', endColorstr='#67c4da', GradientType=0)}.case-studies .case-study,.page-template-template-tour header{background-size:cover;background-repeat:no-repeat;background-position:center}.clearfix{zoom:1}.clearfix:after,.clearfix:before{content:"";display:table}.clearfix:after{clear:both}.no-clearfix{zoom:0}.centered-categories,.centered-content,.centered-content-padding,.centered-footer,.centered-header,.centered-prodFeat{zoom:1;margin:0 auto;width:100%}.no-clearfix:after,.no-clearfix:before{display:none}.centered-categories:after,.centered-categories:before,.centered-content-padding:after,.centered-content-padding:before,.centered-content:after,.centered-content:before,.centered-footer:after,.centered-footer:before,.centered-header:after,.centered-header:before,.centered-prodFeat:after,.centered-prodFeat:before{content:"";display:table}.no-clearfix:after{clear:none}.centered-categories:after,.centered-content-padding:after,.centered-content:after,.centered-footer:after,.centered-header:after,.centered-prodFeat:after{clear:both}.centered-header{max-width:1140px;padding:0 10px}.centered-prodFeat{max-width:950px;padding:0 10px}.centered-content{max-width:790px;padding:0 10px}.centered-content-padding{max-width:950px;padding:0 10px 50px;background-color:#fff}.centered-categories{max-width:1000px}.centered-footer{max-width:670px;padding:0 10px}ol,ul{padding:0;margin:0}.ttl-columns{font-size:0;width:100%;width:calc(100% + 30px)}.ttl-columns .column,.ttl-columns .column-2,.ttl-columns .column-3,.ttl-columns .column-4,.ttl-columns .column-5,.ttl-columns .column-6,.ttl-columns .column-7,.ttl-columns .columnThreeQuarters,.ttl-columns .columnTwoThirds{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px}.ttl-columns .column-2{width:50%}@media screen and (max-width:570px){.ttl-columns .column-2{width:100%}}.ttl-columns .column-3{width:33.33333333%}@media screen and (max-width:570px){.ttl-columns .column-3{width:100%}}.ttl-columns .column-4{width:25%}@media screen and (max-width:768px){.ttl-columns .column-4{width:50%}}.ttl-columns .column-5{width:20%}@media screen and (max-width:768px){.ttl-columns .column-5{width:50%}}.ttl-columns .column-6{width:16.66666667%}@media screen and (max-width:768px){.ttl-columns .column-6{width:33%}}@media screen and (max-width:375px){.ttl-columns .column-6{width:50%}}.ttl-columns .column-7{width:14.28571429%}@media screen and (max-width:768px){.ttl-columns .column-7{width:33%}}.ttl-columns .columnTwoThirds{width:66.6%}@media screen and (max-width:570px){.ttl-columns .columnTwoThirds{width:100%}}.ttl-columns .columnThreeQuarters{width:75%}@media screen and (max-width:768px){.ttl-columns .columnThreeQuarters{width:100%}}.column-container{font-size:0;width:100%;width:calc(100% + 30px)}.column-container .column,.column-container .column-2,.column-container .column-3,.column-container .column-4,.column-container .column-5,.column-container .column-6,.column-container .column-7,.column-container .columnThreeQuarters,.column-container .columnTwoThirds{display:inline-block;padding-right:30px;font-size:15px;vertical-align:top}.column-container .column-2{width:50%}@media screen and (max-width:570px){.column-container .column-2{width:100%}}.column-container .column-3{width:33.33333333%}@media screen and (max-width:570px){.column-container .column-3{width:100%}}.column-container .column-4{width:25%}@media screen and (max-width:768px){.column-container .column-4{width:50%}}.column-container .column-5{width:20%}@media screen and (max-width:768px){.column-container .column-5{width:50%}}.column-container .column-6{width:16.66666667%}@media screen and (max-width:768px){.column-container .column-6{width:33%}}@media screen and (max-width:375px){.column-container .column-6{width:50%}}.column-container .column-7{width:14.28571429%}@media screen and (max-width:768px){.column-container .column-7{width:33%}}.column-container .columnTwoThirds{width:66.6%}@media screen and (max-width:570px){.column-container .columnTwoThirds{width:100%}}.column-container .columnThreeQuarters{width:75%}*,:after,:before{box-sizing:border-box}embed,img,object,video{max-width:100%;border:0;padding:0}.mobile-only{display:none}@media screen and (max-width:768px){.column-container .columnThreeQuarters{width:100%}.mobile-only{display:inherit}.desktop-only{display:none}}header{padding-bottom:50px}header+.chevron-divider{height:175px}.page-template-template-tour header{height:815px;padding:0;margin-bottom:60px;position:relative;overflow:visible}.page-template-template-tour header nav{float:left;margin-top:35px;margin-left:20px;font-size:25px;line-height:30px;color:#67c4da}.page-template-template-tour header .description{clear:both;width:80%;margin:190px auto 0;text-align:center}.page-template-template-tour header h1{font-size:37px;color:#fff;line-height:44px;margin-bottom:160px}.page-template-template-tour header .app-links{color:#fff;margin-top:25px}.page-template-template-tour header .app-links a{color:#fff}.page-template-template-tour header .app-links a:hover{color:#d8127d}.page-template-template-tour header .chevron-divider{position:absolute;bottom:-60px;height:150px}@media screen and (max-width:768px){.page-template-template-tour header{height:600px}.page-template-template-tour header h1{margin-bottom:80px}.page-template-template-tour header .description{margin:160px auto 0;font-size:34px;width:100%}}.page-template-template-companyblue header,.page-template-template-companyblue header+.chevron-divider{background-color:#529dae}.archive header,.blog header,.single-post header{padding-bottom:0}.archive header .chevron-divider,.blog header .chevron-divider,.single-post header .chevron-divider{position:absolute;top:110px;z-index:1}.above-chevron,.case-studies,.subtemplate{position:relative}.archive header h1,.blog header h1,.single-post header h1{color:#fff;font-size:54px;position:relative;z-index:2;margin-top:100px;margin-bottom:50px;text-align:center}.archive header .app-links,.archive header .app-links a,.blog header .app-links,.blog header .app-links a,.single-post header .app-links,.single-post header .app-links a{color:#fff}.archive header+nav,.blog header+nav,.single-post header+nav{background-color:#67c4da;border-top:2px solid rgba(255,255,255,.5)}.archive header+nav ul,.blog header+nav ul,.single-post header+nav ul{font-size:0;width:100%;width:calc(100% + 30px)}.archive header+nav ul .column,.blog header+nav ul .column,.single-post header+nav ul .column{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px}.archive header+nav ul .column-2,.blog header+nav ul .column-2,.single-post header+nav ul .column-2{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:50%}@media screen and (max-width:570px){.archive header+nav ul .column-2,.blog header+nav ul .column-2,.single-post header+nav ul .column-2{width:100%}}.archive header+nav ul .column-3,.blog header+nav ul .column-3,.single-post header+nav ul .column-3{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:33.33333333%}@media screen and (max-width:570px){.archive header+nav ul .column-3,.blog header+nav ul .column-3,.single-post header+nav ul .column-3{width:100%}}.archive header+nav ul .column-4,.blog header+nav ul .column-4,.single-post header+nav ul .column-4{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:25%}@media screen and (max-width:768px){.archive header+nav ul .column-4,.blog header+nav ul .column-4,.single-post header+nav ul .column-4{width:50%}}.archive header+nav ul .column-5,.blog header+nav ul .column-5,.single-post header+nav ul .column-5{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:20%}@media screen and (max-width:768px){.archive header+nav ul .column-5,.blog header+nav ul .column-5,.single-post header+nav ul .column-5{width:50%}}.archive header+nav ul .column-6,.blog header+nav ul .column-6,.single-post header+nav ul .column-6{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:16.66666667%}@media screen and (max-width:768px){.archive header+nav ul .column-6,.blog header+nav ul .column-6,.single-post header+nav ul .column-6{width:33%}}@media screen and (max-width:375px){.archive header+nav ul .column-6,.blog header+nav ul .column-6,.single-post header+nav ul .column-6{width:50%}}.archive header+nav ul .column-7,.blog header+nav ul .column-7,.single-post header+nav ul .column-7{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:14.28571429%}@media screen and (max-width:768px){.archive header+nav ul .column-7,.blog header+nav ul .column-7,.single-post header+nav ul .column-7{width:33%}}.archive header+nav ul .columnTwoThirds,.blog header+nav ul .columnTwoThirds,.single-post header+nav ul .columnTwoThirds{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:66.6%}@media screen and (max-width:570px){.archive header+nav ul .columnTwoThirds,.blog header+nav ul .columnTwoThirds,.single-post header+nav ul .columnTwoThirds{width:100%}}.archive header+nav ul .columnThreeQuarters,.blog header+nav ul .columnThreeQuarters,.single-post header+nav ul .columnThreeQuarters{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:75%}@media screen and (max-width:768px){.archive header+nav ul .columnThreeQuarters,.blog header+nav ul .columnThreeQuarters,.single-post header+nav ul .columnThreeQuarters{width:100%}}.archive header+nav li,.blog header+nav li,.single-post header+nav li{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:16.66666667%}@media screen and (max-width:768px){.archive header+nav li,.blog header+nav li,.single-post header+nav li{width:33%}}@media screen and (max-width:375px){.archive header+nav li,.blog header+nav li,.single-post header+nav li{width:50%}}.archive header+nav a,.blog header+nav a,.single-post header+nav a{display:block;text-align:center;padding:25px 0;font-size:16px;color:#fff}.app-links,.app-links a{font-size:17px;line-height:20px;color:#000;text-transform:uppercase}.archive header+nav a:hover,.blog header+nav a:hover,.single-post header+nav a:hover{background-color:rgba(255,255,255,.5)}.logo{float:left;margin-top:25px}.app-links{float:right;margin-top:35px}.four-oh-four,.subtemplate h1{font-size:34px;text-align:center}.app-links a:hover{color:#d8127d}.above-chevron{margin-top:-100px;margin-bottom:-80px;z-index:3}.four-oh-four{line-height:41px}.four-oh-four .centered-content-padding{min-height:500px}.subtemplate h1{color:#67c4da;line-height:1.2;margin:35px 0}@media screen and (max-width:768px){.subtemplate h1{font-size:30px}}.feature-circles{padding:75px 0 160px}.feature-circles .column-container{width:calc(100% + 100px)}.feature-circles .feature-circle{display:inline-block;vertical-align:top;font-size:15px;width:33.33333333%;padding-right:100px}@media screen and (max-width:570px){.feature-circles .feature-circle{width:100%}}.feature-circles img{width:105px;display:block;margin:0 auto 26px}.feature-circles h1{font-size:20px;color:#d8127d;letter-spacing:1.11px;line-height:24px;margin-bottom:22px;text-align:center}.feature-circles .description{color:#121417;font-size:15px;line-height:19px}@media screen and (max-width:768px){.feature-circles{padding:75px 0 100px}.feature-circles .column-container{width:calc(100% + 50px)}.feature-circles .feature-circle{padding-right:50px}}.case-studies{height:685px;background-color:#888}.case-studies .case-study{position:absolute;top:0;left:0;width:100%;height:100%;transition:all .3s ease-in-out;visibility:visible;opacity:1}.case-studies .centered-header,.case-studies .slide-container{position:relative;width:100%;height:100%}.case-studies .case-study.hidden{visibility:hidden;opacity:0}.case-studies .slide-container{left:0}.case-studies .description{white-space:normal;width:60%;background:rgba(0,0,0,.64);padding:25px;position:absolute;bottom:35px;right:0;font-size:23px;color:#fff;line-height:28px}.case-studies p{margin:0}.case-studies .slider-action{width:80px;height:80px;background-color:#fff;background-position:center;background-repeat:no-repeat;cursor:pointer;position:absolute;top:calc(50% - 40px);z-index:2}.case-studies #back{background-image:url(../../images/left.png);left:0}.case-studies #forward{background-image:url(../../images/right.png);right:0}@media screen and (max-width:768px){.case-studies{height:500px}.case-studies .description{font-size:17px;line-height:20px;width:70%}.case-studies .slider-action{-webkit-transform:scale(.7);transform:scale(.7)}.case-studies #back{-webkit-transform-origin:left;transform-origin:left}.case-studies #forward{-webkit-transform-origin:right;transform-origin:right}}.old-new{padding-top:130px;padding-bottom:175px}.old-new h1{font-size:34px;color:#67c4da;line-height:1.2;margin:35px 0;text-align:center}@media screen and (max-width:768px){.old-new h1{font-size:30px}}.old-new th{font-size:24px;color:#d8127d;line-height:29px;text-transform:uppercase;padding-bottom:15px}.old-new td{border:1px solid #d7e9ef;vertical-align:middle;color:#121417;font-size:15px;line-height:19px;width:50%;padding:45px 0}.old-new td p{width:60%;margin:0 auto}.old-new .new{border-bottom-color:#fff;position:relative;background-color:#d7e9ef}.old-new .new:before{position:absolute;left:-30px;top:calc(50% - 30px);content:'';display:block;width:60px;height:60px;background-image:url(../../images/icon-arrow.png);background-size:60px;background-repeat:no-repeat}.old-new tr:last-of-type .new{border-bottom-color:#d7e9ef}@media screen and (max-width:768px){.old-new{padding-top:20px}.old-new td{text-align:center}.old-new .centered-content{padding:0}}.product-overview{padding:175px 0;border-top:1px solid #979797}.product-overview h1{font-size:34px;color:#67c4da;line-height:1.2;margin:35px 0;text-align:center}@media screen and (max-width:768px){.product-overview h1{font-size:30px}.product-overview{padding:100px 0}.product-overview:first-of-type{border-top:0}.product-overview img{max-width:100%;width:45%;margin-top:10%}.product-overview .text-column{text-align:center}}.product-overview p{color:#121417;font-size:15px;line-height:19px}.blue-box,.blue-box h1{font-size:43px;color:#fff;line-height:52px}.product-overview:nth-of-type(odd) img{float:left}.product-overview:nth-of-type(even) img,.product-overview:nth-of-type(odd) .text-column{float:right}.product-overview .text-column{width:45%}.blue-box{padding:175px 0;background-color:#fbfbfb}.blue-box .blue-copy{background-color:#67c4da;padding:70px 0 110px}.blue-box .blue-copy div{width:80%;margin:0 auto;text-align:center}.blue-box h1{text-align:center}@media screen and (max-width:768px){.blue-box{padding:75px 0}}.sign-up{padding:240px 0 210px;text-align:center}.sign-up a{margin:0 auto}.galleries-marketplaces{padding:145px 0 130px;text-align:center}.galleries-marketplaces h1{font-size:30px;color:#000;line-height:36px;margin-bottom:50px}.galleries-marketplaces img{display:block;margin-bottom:80px}@media screen and (max-width:768px){.galleries-marketplaces{padding:75px 0 30px}.galleries-marketplaces h1{font-size:27px}.galleries-marketplaces a{display:none}}.blog-features{background-color:#fbfbfb;padding:75px 0}.blog-features .blog,.team .team-member{display:inline-block;padding-right:30px;vertical-align:top}.blog-features .blog{font-size:15px;width:33.33333333%;margin-bottom:40px}@media screen and (max-width:570px){.blog-features .blog{width:100%}}.blog-features .blog div{background-color:#fff;padding-bottom:15px;min-height:225px}.careers,.team.tour-page{background-color:#fbfbfb}.blog-features h2{font-size:13px;color:#67c4da;line-height:22.79px;margin:10px 10px 0}.blog-features h1{font-size:17px;color:#595959;line-height:22.79px;text-transform:uppercase;margin:0 10px;text-align:left}.team{color:#121417;font-size:15px;line-height:19px;text-align:center}.team .column-container,.team .intro{text-align:left}.team .intro{margin-bottom:60px}.team p{margin:0}.team .team-member{font-size:15px;width:33.33333333%;text-align:center;margin-bottom:40px}@media screen and (max-width:570px){.team .team-member{width:100%}}.team img{border-radius:100%}.team h1{color:#000;font-size:19px;margin-top:20px;margin-bottom:0}.faq,.team h2{color:#121417}.team h2{font-size:18px;line-height:22px;margin-top:2px}.team.tour-page{padding:70px 0}@media screen and (max-width:768px){.team .intro{text-align:center}.team .button{display:none}}.faq{font-size:17px;line-height:21px}.faq dd,.faq dl,.faq dt{margin:0;padding:0}.faq .featured-faqs{margin-bottom:75px}.faq .featured-faqs dt{font-size:25px;line-height:32px;color:#d8127d;cursor:pointer}.faq .featured-faqs dd{max-height:0;overflow-y:hidden;transition:all .15s ease-in-out;margin-bottom:5px}.faq .featured-faqs dd.open{max-height:800px}.faq .regular-faqs dd{margin-bottom:60px}.values{padding-bottom:150px}.values .column-container{width:calc(100% + 175px)}.values .value{display:inline-block;vertical-align:top;width:50%;color:#121417;font-size:18px;line-height:22px;padding-right:175px}@media screen and (max-width:570px){.values .value{width:100%}}.values .value h1{color:#000;font-size:25px;line-height:15px;margin-bottom:0;text-align:left}.careers{text-align:center;padding:90px 0 140px;margin-bottom:75px}.contact .contact-points,.contact .form{padding-right:30px;display:inline-block;vertical-align:top}.careers a{color:#000;font-size:27px;line-height:32px}.careers a:hover{color:#d8127d}.careers li{margin-bottom:35px}.contact .form{width:75%;color:#121417;font-size:18px;line-height:22px}@media screen and (max-width:768px){.contact .form{width:100%}}.contact .contact-points{font-size:15px;width:25%}@media screen and (max-width:768px){.contact .contact-points{width:50%}}.contact label{color:#121417;font-size:15px;line-height:19px}.contact label.required:after{content:'*';color:#d8127d}.contact input,.contact textarea{margin-bottom:20px;padding:10px;color:#595959;width:80%;margin-top:5px;border:1px solid #979797;outline:0}.contact input[aria-invalid=true],.contact textarea[aria-invalid=true]{border:1px solid #d8127d}.contact input[type=submit]{display:inline-block;padding:25px 40px;border:1px solid #67c4da;font-size:22px;line-height:26px;text-decoration:none;min-width:265px;text-align:center;color:#fff;background-color:#67c4da;width:auto}.contact input[type=submit].blue{color:#fff;background-color:#67c4da;border-color:#67c4da}.contact input[type=submit].blue:hover{background-color:rgba(103,196,218,.5)}.contact input[type=submit].blue-overPic{color:#fff;background-color:#67c4da;border-color:#67c4da}.contact input[type=submit].blue-overPic:hover{background-color:#fff;color:#67c4da}.contact input[type=submit].white-blue{color:#67c4da;background-color:#fff;border-color:#67c4da}.contact input[type=submit].white-blue:hover{background-color:rgba(103,196,218,.5);color:#fff}.contact input[type=submit].small{padding:5px 15px;font-size:14px;color:#fff;background-color:transparent;border-color:#fff;min-width:auto}.contact input[type=submit].small:hover{background-color:rgba(255,255,255,.4);border-color:rgba(255,255,255,.4);color:#fff}.contact input[type=submit]:hover{background-color:rgba(103,196,218,.5)}.contact .contact-point{color:#121417;font-size:18px;line-height:22px}.contact .contact-point h1{font-size:19px;color:#d8127d;text-align:left;margin-bottom:0}.contact .required-info,.contact .wpcf7-not-valid-tip{font-size:15px;line-height:19px;color:#d8127d}.contact .wpcf7-not-valid-tip{margin-top:-20px;margin-bottom:10px}.contact div.wpcf7-validation-errors{border:none;padding:0;margin:0}.press-articles{color:#121417;font-size:18px;line-height:22px;text-align:center}.press-articles blockquote{margin:0}.press-articles .press-article{text-align:left;margin-bottom:35px;padding-bottom:35px;border-bottom:1px solid #979797}.press-articles .press-article h1{color:#000;font-size:19px;margin-bottom:0;text-align:left}.press-articles .press-article h1 a{color:#000}.press-articles .press-article h1 a:hover{color:#67c4da}.downloads .left{float:left}.downloads .right{float:right}.past-events h2,.upcoming-events h2{text-align:center;position:relative;font-size:19px}.past-events h2 span,.upcoming-events h2 span{background-color:#fff;position:relative;z-index:1;padding:0 20px}.past-events h2:after,.upcoming-events h2:after{content:'';display:block;height:1px;background-color:#979797;position:absolute;top:50%;left:0;right:0}.past-events .event,.upcoming-events .event{color:#121417;font-size:18px;line-height:22px;border-top:1px solid #979797;padding-bottom:30px;margin-bottom:30px}.past-events .event h1,.upcoming-events .event h1{color:#000;line-height:1.2;text-align:left;margin-bottom:0;font-size:19px}.past-events .event h1 a,.upcoming-events .event h1 a{color:#000}.past-events .event h1 a:hover,.upcoming-events .event h1 a:hover{color:#d8127d}.past-events .event time,.upcoming-events .event time{color:#121417;font-size:17px;line-height:21px;margin-bottom:5px;display:block}.past-events h2+.event,.upcoming-events h2+.event{border-top:0}.past-events blockquote,.upcoming-events blockquote{margin:0;padding:0}.past-events+.chevron-divider,.upcoming-events+.chevron-divider{height:280px;margin-top:-100px;margin-bottom:-135px;position:relative;z-index:-1}.short-descriptions .short-description{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:33.33333333%}@media screen and (max-width:570px){.short-descriptions .short-description{width:100%}}.blog .column-container{width:calc(100% + 70px)}article.post{padding-top:40px;padding-bottom:50px;border-bottom:2px solid #e5e5e5}article.post h2{margin:0;font-size:12px}article.post .post-categories{list-style:none;font-size:12px}article.post h1{margin-top:0}article.post .image{width:100%}article.post .image img{display:block;max-width:100%;width:100%}.blog-column,.blog-sidebar{display:inline-block;vertical-align:top;font-size:15px;padding-right:70px}article.post .meta{background-image:url(../../images/svg/ascribe-chevron.svg);background-position:bottom;width:100%;background-size:100%;opacity:1;line-height:75px;height:75px;padding-left:15px;margin-bottom:35px}.blog-sidebar .sidebar-blog-features .blog:hover,.blog-sidebar .sidebar-blog-features a:hover{opacity:.3}@media screen and (max-width:768px){article.post .meta{background-size:120%}}.blog-column{width:66.6%}@media screen and (max-width:570px){.blog-column{width:100%}}.blog-sidebar{width:33.33333333%;padding-top:40px}.blog-sidebar img{display:block;margin-bottom:60px}.blog-sidebar .sidebar-blog-features{color:#121417;font-size:18px;line-height:22px}.blog-sidebar .sidebar-blog-features h1{font-size:19px;color:#d8127d;margin-bottom:0}.blog-sidebar .sidebar-blog-features time{font-size:18px;display:block;margin-bottom:5px}.blog-sidebar .sidebar-blog-features a{color:#000}.blog-sidebar .sidebar-blog-features .blog{margin-bottom:70px}@media screen and (max-width:570px){.blog-sidebar{width:50%;margin:0 auto}}.single-post .entry{color:#121417;font-size:18px;line-height:22px;width:80%}footer,footer a{font-size:14px;line-height:25px;color:#fff}.single-post .article-post{border-bottom:0}.page-template-template-companyblue .subtemplate:first-of-type .centered-content-padding{background-color:transparent}footer a{width:100%}footer a:hover{color:#fff}footer .bottom-footer,footer .bottom-footer a{color:#1e1e1e;font-size:13px;line-height:14px}footer .top-footer{background-color:#8c8c8c;padding:50px 0 40px}footer .top-footer ul{-webkit-columns:3;-moz-columns:3;columns:3;width:75%;float:left}footer .contact{width:25%;float:right}footer .bottom-footer{padding:20px 0 10px}footer .bottom-footer .menu{float:left;margin-left:15px}footer .bottom-footer .menu li{display:inline-block;border-left:1px solid #121417;padding:0 15px}footer .bottom-footer .menu li:nth-of-type(1){width:60px}footer .bottom-footer .menu li:nth-of-type(2){width:130px}footer .bottom-footer .social{float:right;position:relative;top:-2px}footer .bottom-footer .social li{display:inline-block}footer .copyright{float:left}footer .button{margin-bottom:10px}
\ No newline at end of file
+/*! normalize.css v3.0.1 | MIT License | git.io/normalize */legend,td,th{padding:0}.wrapper,header{overflow:hidden}.page-template-template-tour header,.page-template-template-tour header nav ul li.current-menu-item a,.wrapper,sub,sup{position:relative}.old-new table,table{border-collapse:collapse}.careers ul,.page-template-template-tour header ul,footer ul{list-style:none}html{-ms-text-size-adjust:100%;-webkit-text-size-adjust:100%}body{margin:0}article,aside,details,figcaption,figure,footer,header,hgroup,main,nav,section,summary{display:block}audio,canvas,progress,video{display:inline-block;vertical-align:baseline}audio:not([controls]){display:none;height:0}[hidden],template{display:none}a:active,a:hover{outline:0}abbr[title]{border-bottom:1px dotted}b,optgroup,strong{font-weight:700}dfn{font-style:italic}h1{margin:.67em 0}mark{background:#ff0;color:#000}small{font-size:80%}sub,sup{font-size:75%;line-height:0;vertical-align:baseline}sup{top:-.5em}sub{bottom:-.25em}figure{margin:1em 40px}pre,textarea{overflow:auto}code,kbd,pre,samp{font-family:monospace,monospace;font-size:1em}button,input,optgroup,select,textarea{color:inherit;font:inherit;margin:0}button{overflow:visible}button,select{text-transform:none}button,html input[type=button],input[type=reset],input[type=submit]{-webkit-appearance:button;cursor:pointer}button[disabled],html input[disabled]{cursor:default}.faq .featured-faqs dt,.page-template-template-tour header nav ul:hover,.page-template-template-tour header nav:hover{cursor:pointer}button::-moz-focus-inner,input::-moz-focus-inner{border:0;padding:0}input{line-height:normal}input[type=checkbox],input[type=radio]{box-sizing:border-box;padding:0}input[type=number]::-webkit-inner-spin-button,input[type=number]::-webkit-outer-spin-button{height:auto}input[type=search]{-webkit-appearance:textfield;box-sizing:content-box}input[type=search]::-webkit-search-cancel-button,input[type=search]::-webkit-search-decoration{-webkit-appearance:none}fieldset{border:1px solid silver;margin:0 2px;padding:.35em .625em .75em}legend{border:0}table{border-spacing:0}@media print{blockquote,img,pre,tr{page-break-inside:avoid}*{background:0 0!important;color:#000!important;text-shadow:none!important;-webkit-filter:none!important;filter:none!important;-ms-filter:none!important}a,a:visited{color:#444!important;text-decoration:underline}a[href]:after{content:" (" attr(href) ")"}abbr[title]:after{content:" (" attr(title) ")"}.ir a:after,a[href^="#"]:after,a[href^="javascript:"]:after{content:""}blockquote,pre{border:1px solid #999}thead{display:table-header-group}@page{margin:.5cm}h2,h3,p{orphans:3;widows:3}h2,h3{page-break-after:avoid}}.button,a{text-decoration:none}body,html{height:100%;color:#121417;font-size:15px;line-height:19px;font-smoothing:antialiased;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;background-color:#fff}body.page-template-template-companyblue,html.page-template-template-companyblue{color:#121417;font-size:18px;line-height:22px}a{background:0 0;color:#67c4da}a:hover{color:#d8127d}.app-links,.app-links a,.blog-features h1,.blog-features h2,.blog-sidebar .sidebar-blog-features,.blue-box,.blueBoxCopy,.button.small,.careers a,.contact .contact-point,.contact .form,.contact .required-info,.contact .wpcf7-not-valid-tip,.contact input[type=submit].small,.contact label,.copyText,.copyTextMedium,.copyTextSmall,.faq,.feature-circles .description,.feature-circles h1,.featureBlogDesc,.featureBlogTitle,.featureCircleH1,.fontLight,.footerText,.galleries-marketplaces h1,.galleriesPressTitle,.h1,.h3,.h5,.heroText,.old-new h1,.old-new td,.old-new th,.oldWayNewWayTH,.page-template-template-tour header h1,.page-template-template-tour header nav,.past-events .event,.past-events .event time,.press-articles,.product-overview h1,.product-overview p,.sectionHeader,.signInUpText,.single-post .entry,.subsectionHeader,.subtemplate h1,.team,.team h2,.tourNavText,.upcoming-events .event,.upcoming-events .event time,.values .value,article.post .post-categories,article.post h2,body,body.page-template-template-companyblue,footer,footer a,h1,h3,h5,html,html.page-template-template-companyblue{font-family:canada-type-gibson,sans-serif;font-weight:200}.archive header .app-links a:hover,.archive header+nav a,.blog header .app-links a:hover,.blog header+nav a,.blog-sidebar .sidebar-blog-features h1,.blue-box h1,.blueBoxTitle,.button,.case-studies .description,.caseStudyText,.contact .contact-point h1,.contact input[type=submit],.faq .featured-faqs dt,.faq .regular-faqs dt,.fontRegular,.h2,.h4,.h6,.past-events .event h1,.press-articles .press-article h1,.single-post header .app-links a:hover,.single-post header+nav a,.team h1,.teamName,.upcoming-events .event h1,.values .value h1,footer a:hover,h2,h4,h6{font-family:canada-type-gibson,sans-serif;font-weight:400}.sectionHeader{font-size:34px;color:#67c4da;line-height:1.2;margin:35px 0;text-align:center}@media screen and (max-width:768px){.sectionHeader{font-size:30px}}.subsectionHeader{font-size:31px;color:#000;line-height:37px;text-align:center}.h1,.h2,.h3,h1,h2,h3{color:#d8127d}.h1,.h2,.h3,.h4,.h5,h1,h2,h3,h4,h5{line-height:1.2}.h1,h1{font-size:36px}.h2,h2{font-size:26px}.h3,h3{font-size:27px}.h4,.h5,h4,h5{font-size:26px;color:#000}.h6,h6{color:#d8127d;font-size:15px;line-height:19px}.copyText{color:#121417;font-size:18px;line-height:22px}.copyTextMedium{color:#121417;font-size:17px;line-height:21px}.copyTextSmall{color:#121417;font-size:15px;line-height:19px}.heroText{font-size:37px;color:#fff;line-height:44px}.tourNavText{font-size:25px;line-height:30px;color:#67c4da}.signInUpText{font-size:17px;line-height:20px;color:#fff;text-transform:uppercase}.featureCircleH1{font-size:20px;color:#d8127d;letter-spacing:1.11px;line-height:24px;margin-bottom:22px}.caseStudyText{font-size:23px;color:#fff;line-height:28px}.oldWayNewWayTH{font-size:24px;color:#d8127d;line-height:29px}.blueBoxCopy,.blueBoxTitle{font-size:43px;color:#fff;line-height:52px}.blueBoxTitle{text-align:center}.galleriesPressTitle{font-size:30px;color:#000;line-height:36px;margin-bottom:50px}.featureBlogDesc{font-size:13px;color:#67c4da;line-height:22.79px}.featureBlogTitle{font-size:17px;color:#595959;line-height:22.79px;text-transform:uppercase}.teamName{color:#000;font-size:19px}.footerText{font-size:14px;color:#fff;line-height:25px}.subfooterText{color:#1e1e1e;font-size:13px;line-height:14px}.button{display:inline-block;padding:25px 40px;border:1px solid;font-size:22px;line-height:26px;min-width:265px;text-align:center}.button.blue,.button.blue-overPic,.button.white-blue{border-color:#67c4da}.button.blue{color:#fff;background-color:#67c4da}.button.blue:hover{background-color:rgba(103,196,218,.5)}.button.blue-overPic{color:#fff;background-color:#67c4da}.button.blue-overPic:hover,.button.white-blue{color:#67c4da;background-color:#fff}.button.white-blue:hover{background-color:rgba(103,196,218,.5);color:#fff}.button.small{padding:5px 15px;font-size:14px;color:#fff;background-color:transparent;border-color:#fff;min-width:auto}.button.small:hover{background-color:rgba(255,255,255,.4);border-color:rgba(255,255,255,.4);color:#fff}.chevron-divider{background-image:url(../../images/svg/ascribe-chevron.svg);background-position:bottom;width:100%;background-size:100%;height:150px}@media screen and (max-width:768px){.chevron-divider{background-size:120%}}.social-icon{width:21px;height:21px;padding:1px;fill:#fff;background-color:#b8b8b8;border-radius:5px}.social-icon:hover{background-color:rgba(184,184,184,.4)}hr{box-sizing:content-box;border:0;height:2px;background:#979797;margin:40px 0}.archive header,.blog header,.blueGradient,.page-template-template-companyblue .subtemplate:first-of-type,.single-post header{background:url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiA/Pgo8c3ZnIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdmlld0JveD0iMCAwIDEgMSIgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSI+CiAgPGxpbmVhckdyYWRpZW50IGlkPSJncmFkLXVjZ2ctZ2VuZXJhdGVkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgeDE9IjAlIiB5MT0iMCUiIHgyPSIwJSIgeTI9IjEwMCUiPgogICAgPHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iIzUxOWNhZCIgc3RvcC1vcGFjaXR5PSIxIi8+CiAgICA8c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29sb3I9IiM2N2M0ZGEiIHN0b3Atb3BhY2l0eT0iMSIvPgogIDwvbGluZWFyR3JhZGllbnQ+CiAgPHJlY3QgeD0iMCIgeT0iMCIgd2lkdGg9IjEiIGhlaWdodD0iMSIgZmlsbD0idXJsKCNncmFkLXVjZ2ctZ2VuZXJhdGVkKSIgLz4KPC9zdmc+);background:linear-gradient(to bottom,#519cad 0,#67c4da 100%);filter:progid:DXImageTransform.Microsoft.gradient(startColorstr='#519cad', endColorstr='#67c4da', GradientType=0)}.clearfix{zoom:1}.clearfix:after,.clearfix:before{content:"";display:table}.clearfix:after{clear:both}.no-clearfix{zoom:0}.centered-categories,.centered-content,.centered-content-padding,.centered-footer,.centered-header,.centered-prodFeat{zoom:1;margin:0 auto;width:100%}.no-clearfix:after,.no-clearfix:before{display:none}.centered-categories:after,.centered-categories:before,.centered-content-padding:after,.centered-content-padding:before,.centered-content:after,.centered-content:before,.centered-footer:after,.centered-footer:before,.centered-header:after,.centered-header:before,.centered-prodFeat:after,.centered-prodFeat:before{content:"";display:table}.no-clearfix:after{clear:none}.centered-categories:after,.centered-content-padding:after,.centered-content:after,.centered-footer:after,.centered-header:after,.centered-prodFeat:after{clear:both}.centered-header{max-width:1140px;padding:0 10px}.centered-prodFeat{max-width:950px;padding:0 10px}.centered-content{max-width:790px;padding:0 10px}.centered-content-padding{max-width:950px;padding:0 10px 50px;background-color:#fff}.centered-categories{max-width:1000px}.centered-footer{max-width:670px;padding:0 10px}ol,ul{padding:0;margin:0}.ttl-columns{font-size:0;width:100%;width:calc(100% + 30px)}.ttl-columns .column,.ttl-columns .column-2,.ttl-columns .column-3,.ttl-columns .column-4,.ttl-columns .column-5,.ttl-columns .column-6,.ttl-columns .column-7,.ttl-columns .columnThreeQuarters,.ttl-columns .columnTwoThirds{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px}.ttl-columns .column-2{width:50%}@media screen and (max-width:570px){.ttl-columns .column-2{width:100%}}.ttl-columns .column-3{width:33.33333333%}@media screen and (max-width:570px){.ttl-columns .column-3{width:100%}}.ttl-columns .column-4{width:25%}@media screen and (max-width:768px){.ttl-columns .column-4{width:50%}}.ttl-columns .column-5{width:20%}@media screen and (max-width:768px){.ttl-columns .column-5{width:50%}}.ttl-columns .column-6{width:16.66666667%}@media screen and (max-width:768px){.ttl-columns .column-6{width:33%}}@media screen and (max-width:375px){.ttl-columns .column-6{width:50%}}.ttl-columns .column-7{width:14.28571429%}@media screen and (max-width:768px){.ttl-columns .column-7{width:33%}}.ttl-columns .columnTwoThirds{width:66.6%}@media screen and (max-width:570px){.ttl-columns .columnTwoThirds{width:100%}}.ttl-columns .columnThreeQuarters{width:75%}@media screen and (max-width:768px){.ttl-columns .columnThreeQuarters{width:100%}}.column-container{font-size:0;width:100%;width:calc(100% + 30px)}.column-container .column,.column-container .column-2,.column-container .column-3,.column-container .column-4,.column-container .column-5,.column-container .column-6,.column-container .column-7,.column-container .columnThreeQuarters,.column-container .columnTwoThirds{display:inline-block;padding-right:30px;font-size:15px;vertical-align:top}.column-container .column-2{width:50%}@media screen and (max-width:570px){.column-container .column-2{width:100%}}.column-container .column-3{width:33.33333333%}@media screen and (max-width:570px){.column-container .column-3{width:100%}}.column-container .column-4{width:25%}@media screen and (max-width:768px){.column-container .column-4{width:50%}}.column-container .column-5{width:20%}@media screen and (max-width:768px){.column-container .column-5{width:50%}}.column-container .column-6{width:16.66666667%}@media screen and (max-width:768px){.column-container .column-6{width:33%}}@media screen and (max-width:375px){.column-container .column-6{width:50%}}.column-container .column-7{width:14.28571429%}@media screen and (max-width:768px){.column-container .column-7{width:33%}}.column-container .columnTwoThirds{width:66.6%}@media screen and (max-width:570px){.column-container .columnTwoThirds{width:100%}}.column-container .columnThreeQuarters{width:75%}*,:after,:before{box-sizing:border-box}embed,img,object,video{max-width:100%;border:0;padding:0}.mobile-only{display:none}@media screen and (max-width:768px){.column-container .columnThreeQuarters{width:100%}.mobile-only{display:inherit}.desktop-only{display:none}}header{padding-bottom:50px}header+.chevron-divider{height:175px}.page-template-template-tour header{height:815px;padding:0;margin-bottom:60px;background-size:cover;background-repeat:no-repeat;background-position:center;overflow:visible}.page-template-template-tour header nav{float:left;margin-top:35px;margin-left:20px;font-size:25px;line-height:30px;color:#67c4da}.page-template-template-tour header nav:hover a,.page-template-template-tour header nav:hover ul li a:after,.page-template-template-tour header nav:hover ul:before{color:#d8127d}.page-template-template-tour header nav ul{display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;padding:0 35px;position:relative;-webkit-flex-direction:column}.page-template-template-tour header nav ul.active li{display:-webkit-flex;display:-ms-flexbox;display:flex}.page-template-template-tour header nav ul li{-webkit-flex-grow:1;-ms-flex-positive:1;flex-grow:1;-webkit-order:2;-ms-flex-order:2;order:2;display:none}.page-template-template-tour header nav ul li.current-menu-item{-webkit-order:1;-ms-flex-order:1;order:1;display:-webkit-flex;display:-ms-flexbox;display:flex}.page-template-template-tour header nav ul li.current-menu-item a:after{content:'▼';display:inline-block;position:absolute;top:3px;right:-34px}.page-template-template-tour header nav ul:before{content:'for ';display:inline-block;position:absolute;top:0;left:0}.page-template-template-tour header .description{clear:both;width:80%;margin:190px auto 0;text-align:center}.page-template-template-tour header h1{font-size:37px;color:#fff;line-height:44px;margin-bottom:160px}.page-template-template-tour header .app-links{color:#fff;margin-top:25px}.page-template-template-tour header .app-links a{color:#fff}.page-template-template-tour header .app-links a:hover{color:#d8127d}.page-template-template-tour header .chevron-divider{position:absolute;bottom:-60px;height:150px}@media screen and (max-width:768px){.page-template-template-tour header{height:600px}.page-template-template-tour header h1{margin-bottom:80px}.page-template-template-tour header .description{margin:160px auto 0;font-size:34px;width:100%}}.page-template-template-companyblue header,.page-template-template-companyblue header+.chevron-divider{background-color:#529dae}.archive header,.blog header,.single-post header{padding-bottom:0}.archive header .chevron-divider,.blog header .chevron-divider,.single-post header .chevron-divider{position:absolute;top:110px;z-index:1}.archive header h1,.blog header h1,.single-post header h1{color:#fff;font-size:54px;position:relative;z-index:2;margin-top:100px;margin-bottom:50px;text-align:center}.archive header .app-links,.archive header .app-links a,.blog header .app-links,.blog header .app-links a,.single-post header .app-links,.single-post header .app-links a{color:#fff}.archive header+nav,.blog header+nav,.single-post header+nav{background-color:#67c4da;border-top:2px solid rgba(255,255,255,.5)}.archive header+nav ul,.blog header+nav ul,.single-post header+nav ul{font-size:0;width:100%;width:calc(100% + 30px)}.archive header+nav ul .column,.blog header+nav ul .column,.single-post header+nav ul .column{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px}.archive header+nav ul .column-2,.blog header+nav ul .column-2,.single-post header+nav ul .column-2{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:50%}@media screen and (max-width:570px){.archive header+nav ul .column-2,.blog header+nav ul .column-2,.single-post header+nav ul .column-2{width:100%}}.archive header+nav ul .column-3,.blog header+nav ul .column-3,.single-post header+nav ul .column-3{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:33.33333333%}@media screen and (max-width:570px){.archive header+nav ul .column-3,.blog header+nav ul .column-3,.single-post header+nav ul .column-3{width:100%}}.archive header+nav ul .column-4,.blog header+nav ul .column-4,.single-post header+nav ul .column-4{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:25%}@media screen and (max-width:768px){.archive header+nav ul .column-4,.blog header+nav ul .column-4,.single-post header+nav ul .column-4{width:50%}}.archive header+nav ul .column-5,.blog header+nav ul .column-5,.single-post header+nav ul .column-5{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:20%}@media screen and (max-width:768px){.archive header+nav ul .column-5,.blog header+nav ul .column-5,.single-post header+nav ul .column-5{width:50%}}.archive header+nav ul .column-6,.blog header+nav ul .column-6,.single-post header+nav ul .column-6{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:16.66666667%}@media screen and (max-width:768px){.archive header+nav ul .column-6,.blog header+nav ul .column-6,.single-post header+nav ul .column-6{width:33%}}@media screen and (max-width:375px){.archive header+nav ul .column-6,.blog header+nav ul .column-6,.single-post header+nav ul .column-6{width:50%}}.archive header+nav ul .column-7,.blog header+nav ul .column-7,.single-post header+nav ul .column-7{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:14.28571429%}@media screen and (max-width:768px){.archive header+nav ul .column-7,.blog header+nav ul .column-7,.single-post header+nav ul .column-7{width:33%}}.archive header+nav ul .columnTwoThirds,.blog header+nav ul .columnTwoThirds,.single-post header+nav ul .columnTwoThirds{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:66.6%}@media screen and (max-width:570px){.archive header+nav ul .columnTwoThirds,.blog header+nav ul .columnTwoThirds,.single-post header+nav ul .columnTwoThirds{width:100%}}.archive header+nav ul .columnThreeQuarters,.blog header+nav ul .columnThreeQuarters,.single-post header+nav ul .columnThreeQuarters{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:75%}@media screen and (max-width:768px){.archive header+nav ul .columnThreeQuarters,.blog header+nav ul .columnThreeQuarters,.single-post header+nav ul .columnThreeQuarters{width:100%}}.archive header+nav li,.blog header+nav li,.single-post header+nav li{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:16.66666667%}@media screen and (max-width:768px){.archive header+nav li,.blog header+nav li,.single-post header+nav li{width:33%}}@media screen and (max-width:375px){.archive header+nav li,.blog header+nav li,.single-post header+nav li{width:50%}}.archive header+nav a,.blog header+nav a,.single-post header+nav a{display:block;text-align:center;padding:25px 0;font-size:16px;color:#fff}.app-links,.app-links a{font-size:17px;line-height:20px;color:#000;text-transform:uppercase}.archive header+nav a:hover,.blog header+nav a:hover,.single-post header+nav a:hover{background-color:rgba(255,255,255,.5)}.logo{float:left;margin-top:25px}.app-links{float:right;margin-top:35px}.four-oh-four,.subtemplate h1{font-size:34px;text-align:center}.app-links a:hover{color:#d8127d}.above-chevron{margin-top:-100px;margin-bottom:-80px;position:relative;z-index:3}.four-oh-four{line-height:41px}.four-oh-four .centered-content-padding{min-height:500px}.subtemplate{position:relative}.subtemplate h1{color:#67c4da;line-height:1.2;margin:35px 0}@media screen and (max-width:768px){.subtemplate h1{font-size:30px}}.feature-circles{padding:75px 0 160px}.feature-circles .column-container{width:calc(100% + 100px)}.feature-circles .feature-circle{display:inline-block;vertical-align:top;font-size:15px;width:33.33333333%;padding-right:100px}@media screen and (max-width:570px){.feature-circles .feature-circle{width:100%}}.feature-circles .surround-circle{display:inline-block;vertical-align:top;font-size:15px;text-align:center;position:relative;width:30%;padding:80px 50px 170px}@media screen and (max-width:570px){.feature-circles .surround-circle{width:100%}}.feature-circles .surround-circle:before{top:0;left:5%;width:90%;background:url(../img/circle.png) center top no-repeat;background-size:100%;height:100%;content:'';position:absolute}.feature-circles img{width:105px;display:block;margin:0 auto 26px}.feature-circles h1{font-size:20px;color:#d8127d;letter-spacing:1.11px;line-height:24px;margin-bottom:22px;text-align:center}.feature-circles .description{color:#121417;font-size:15px;line-height:19px}@media screen and (max-width:768px){.feature-circles{padding:75px 0 100px}.feature-circles .column-container{width:calc(100% + 50px)}.feature-circles .feature-circle{padding-right:50px}}.case-studies{height:685px;background-color:#888;position:relative}.case-studies .case-study{position:absolute;top:0;left:0;width:100%;height:100%;background-size:cover;background-repeat:no-repeat;background-position:center;transition:all .3s ease-in-out;visibility:visible;opacity:1}.case-studies .centered-header,.case-studies .slide-container{position:relative;width:100%;height:100%}.case-studies .case-study.hidden{visibility:hidden;opacity:0}.case-studies .slide-container{left:0}.case-studies .description{white-space:normal;width:60%;background:rgba(0,0,0,.64);padding:25px;position:absolute;bottom:35px;right:0;font-size:23px;color:#fff;line-height:28px}.case-studies p{margin:0}.case-studies .slider-action{width:80px;height:80px;background-color:#fff;background-position:center;background-repeat:no-repeat;cursor:pointer;position:absolute;top:calc(50% - 40px);z-index:2}.case-studies #back{background-image:url(../../images/left.png);left:0}.case-studies #forward{background-image:url(../../images/right.png);right:0}@media screen and (max-width:768px){.case-studies{height:500px}.case-studies .description{font-size:17px;line-height:20px;width:70%}.case-studies .slider-action{-webkit-transform:scale(.7);transform:scale(.7)}.case-studies #back{-webkit-transform-origin:left;transform-origin:left}.case-studies #forward{-webkit-transform-origin:right;transform-origin:right}}.old-new{padding-top:130px;padding-bottom:175px}.old-new h1{font-size:34px;color:#67c4da;line-height:1.2;margin:35px 0;text-align:center}@media screen and (max-width:768px){.old-new h1{font-size:30px}}.old-new th{font-size:24px;color:#d8127d;line-height:29px;text-transform:uppercase;padding-bottom:15px}.old-new td{border:1px solid #d7e9ef;vertical-align:middle;color:#121417;font-size:15px;line-height:19px;width:50%;padding:45px 0}.old-new td p{width:60%;margin:0 auto}.old-new .new{border-bottom-color:#fff;position:relative;background-color:#d7e9ef}.old-new .new:before{position:absolute;left:-30px;top:calc(50% - 30px);content:'';display:block;width:60px;height:60px;background-image:url(../../images/icon-arrow.png);background-size:60px;background-repeat:no-repeat}.old-new tr:last-of-type .new{border-bottom-color:#d7e9ef}@media screen and (max-width:768px){.old-new{padding-top:20px}.old-new td{text-align:center}.old-new .centered-content{padding:0}}.product-overview{padding:175px 0;border-top:1px solid #979797}.product-overview h1{font-size:34px;color:#67c4da;line-height:1.2;margin:35px 0;text-align:center}@media screen and (max-width:768px){.product-overview h1{font-size:30px}.product-overview{padding:100px 0}.product-overview:first-of-type{border-top:0}.product-overview img{max-width:100%;width:45%;margin-top:10%}.product-overview .text-column{text-align:center}}.product-overview p{color:#121417;font-size:15px;line-height:19px}.blue-box,.blue-box h1{font-size:43px;color:#fff;line-height:52px}.product-overview:nth-of-type(odd) img{float:left}.product-overview:nth-of-type(even) img,.product-overview:nth-of-type(odd) .text-column{float:right}.product-overview .text-column{width:45%}.blue-box{padding:175px 0;background-color:#fbfbfb}.blue-box .blue-copy{background-color:#67c4da;padding:70px 0 110px}.blue-box .blue-copy div{width:80%;margin:0 auto;text-align:center}.blue-box h1{text-align:center}@media screen and (max-width:768px){.blue-box{padding:75px 0}}.sign-up{padding:240px 0 210px;text-align:center}.sign-up a{margin:0 auto}.galleries-marketplaces{padding:145px 0 130px;text-align:center}.galleries-marketplaces h1{font-size:30px;color:#000;line-height:36px;margin-bottom:50px}.galleries-marketplaces img{display:block;margin-bottom:80px}@media screen and (max-width:768px){.galleries-marketplaces{padding:75px 0 30px}.galleries-marketplaces h1{font-size:27px}.galleries-marketplaces a{display:none}}.blog-features{background-color:#fbfbfb;padding:75px 0}.blog-features .blog,.team .team-member{display:inline-block;padding-right:30px;vertical-align:top}.blog-features .blog{font-size:15px;width:33.33333333%;margin-bottom:40px}@media screen and (max-width:570px){.blog-features .blog{width:100%}}.blog-features .blog div{background-color:#fff;padding-bottom:15px;min-height:225px}.careers,.team.tour-page{background-color:#fbfbfb}.blog-features h2{font-size:13px;color:#67c4da;line-height:22.79px;margin:10px 10px 0}.blog-features h1{font-size:17px;color:#595959;line-height:22.79px;text-transform:uppercase;margin:0 10px;text-align:left}.team{color:#121417;font-size:15px;line-height:19px;text-align:center}.team .column-container,.team .intro{text-align:left}.team .intro{margin-bottom:60px}.team p{margin:0}.team .team-member{font-size:15px;width:33.33333333%;text-align:center;margin-bottom:40px}@media screen and (max-width:570px){.team .team-member{width:100%}}.team img{border-radius:100%}.team h1{color:#000;font-size:19px;margin-top:20px;margin-bottom:0}.faq,.team h2{color:#121417}.team h2{font-size:18px;line-height:22px;margin-top:2px}.team.tour-page{padding:70px 0}@media screen and (max-width:768px){.team .intro{text-align:center}.team .button{display:none}}.faq{font-size:17px;line-height:21px}.faq dd,.faq dl,.faq dt{margin:0;padding:0}.faq .featured-faqs{margin-bottom:75px}.faq .featured-faqs dt{font-size:25px;line-height:32px;color:#d8127d}.faq .featured-faqs dd{max-height:0;overflow-y:hidden;transition:all .15s ease-in-out;margin-bottom:5px}.faq .featured-faqs dd.open{max-height:800px}.faq .regular-faqs dd{margin-bottom:60px}.values{padding-bottom:150px}.values .column-container{width:calc(100% + 175px)}.values .value{display:inline-block;vertical-align:top;width:50%;color:#121417;font-size:18px;line-height:22px;padding-right:175px}@media screen and (max-width:570px){.values .value{width:100%}}.values .value h1{color:#000;font-size:25px;line-height:15px;margin-bottom:0;text-align:left}.careers{text-align:center;padding:90px 0 140px;margin-bottom:75px}.contact .contact-points,.contact .form{padding-right:30px;display:inline-block;vertical-align:top}.careers a{color:#000;font-size:27px;line-height:32px}.careers a:hover{color:#d8127d}.careers li{margin-bottom:35px}.contact .form{width:75%;color:#121417;font-size:18px;line-height:22px}@media screen and (max-width:768px){.contact .form{width:100%}}.contact .contact-points{font-size:15px;width:25%}@media screen and (max-width:768px){.contact .contact-points{width:50%}}.contact label{color:#121417;font-size:15px;line-height:19px}.contact label.required:after{content:'*';color:#d8127d}.contact input,.contact textarea{margin-bottom:20px;padding:10px;color:#595959;width:80%;margin-top:5px;border:1px solid #979797;outline:0}.contact input[aria-invalid=true],.contact textarea[aria-invalid=true]{border:1px solid #d8127d}.contact input[type=submit]{display:inline-block;padding:25px 40px;border:1px solid #67c4da;font-size:22px;line-height:26px;text-decoration:none;min-width:265px;text-align:center;color:#fff;background-color:#67c4da;width:auto}.contact input[type=submit].blue{color:#fff;background-color:#67c4da;border-color:#67c4da}.contact input[type=submit].blue:hover{background-color:rgba(103,196,218,.5)}.contact input[type=submit].blue-overPic{color:#fff;background-color:#67c4da;border-color:#67c4da}.contact input[type=submit].blue-overPic:hover{background-color:#fff;color:#67c4da}.contact input[type=submit].white-blue{color:#67c4da;background-color:#fff;border-color:#67c4da}.contact input[type=submit].white-blue:hover{background-color:rgba(103,196,218,.5);color:#fff}.contact input[type=submit].small{padding:5px 15px;font-size:14px;color:#fff;background-color:transparent;border-color:#fff;min-width:auto}.contact input[type=submit].small:hover{background-color:rgba(255,255,255,.4);border-color:rgba(255,255,255,.4);color:#fff}.contact input[type=submit]:hover{background-color:rgba(103,196,218,.5)}.contact .contact-point{color:#121417;font-size:18px;line-height:22px}.contact .contact-point h1{font-size:19px;color:#d8127d;text-align:left;margin-bottom:0}.contact .required-info,.contact .wpcf7-not-valid-tip{font-size:15px;line-height:19px;color:#d8127d}.contact .wpcf7-not-valid-tip{margin-top:-20px;margin-bottom:10px}.contact div.wpcf7-validation-errors{border:none;padding:0;margin:0}.press-articles{color:#121417;font-size:18px;line-height:22px;text-align:center}.press-articles blockquote{margin:0}.press-articles .press-article{text-align:left;margin-bottom:35px;padding-bottom:35px;border-bottom:1px solid #979797}.press-articles .press-article h1{color:#000;font-size:19px;margin-bottom:0;text-align:left}.press-articles .press-article h1 a{color:#000}.press-articles .press-article h1 a:hover{color:#67c4da}.downloads .left{float:left}.downloads .right{float:right}.past-events h2,.upcoming-events h2{text-align:center;position:relative;font-size:19px}.past-events h2 span,.upcoming-events h2 span{background-color:#fff;position:relative;z-index:1;padding:0 20px}.past-events h2:after,.upcoming-events h2:after{content:'';display:block;height:1px;background-color:#979797;position:absolute;top:50%;left:0;right:0}.past-events .event,.upcoming-events .event{color:#121417;font-size:18px;line-height:22px;border-top:1px solid #979797;padding-bottom:30px;margin-bottom:30px}.past-events .event h1,.upcoming-events .event h1{color:#000;line-height:1.2;text-align:left;margin-bottom:0;font-size:19px}.past-events .event h1 a,.upcoming-events .event h1 a{color:#000}.past-events .event h1 a:hover,.upcoming-events .event h1 a:hover{color:#d8127d}.past-events .event time,.upcoming-events .event time{color:#121417;font-size:17px;line-height:21px;margin-bottom:5px;display:block}.past-events h2+.event,.upcoming-events h2+.event{border-top:0}.past-events blockquote,.upcoming-events blockquote{margin:0;padding:0}.past-events+.chevron-divider,.upcoming-events+.chevron-divider{height:280px;margin-top:-100px;margin-bottom:-135px;position:relative;z-index:-1}.short-descriptions .short-description{display:inline-block;vertical-align:top;padding-right:30px;font-size:15px;width:33.33333333%}@media screen and (max-width:570px){.short-descriptions .short-description{width:100%}}.content-boxed,.content-boxed .centered-content-padding{background-color:#fbfbfb}.content-boxed .centered-content>div{border:1px solid #d8127d;background-color:#fff;padding:30px}.content-boxed .centered-content>div>ul{margin:30px;overflow:hidden}.content-boxed .centered-content>div>ul>li{float:left;clear:left;width:100%;text-align:right}.content-boxed .centered-content>div>ul ul{width:70%;float:right;text-align:left}.content-boxed .centered-content p{max-width:640px}.content-boxed .centered-content img{margin:30px 0}.blog .column-container{width:calc(100% + 70px)}article.post{padding-top:40px;padding-bottom:50px;border-bottom:2px solid #e5e5e5}article.post h2{margin:0;font-size:12px}article.post .post-categories{list-style:none;font-size:12px}article.post h1{margin-top:0}article.post .image{width:100%}article.post .image img{display:block;max-width:100%;width:100%}.blog-column,.blog-sidebar{display:inline-block;vertical-align:top;font-size:15px;padding-right:70px}article.post .meta{background-image:url(../../images/svg/ascribe-chevron.svg);background-position:bottom;width:100%;background-size:100%;opacity:1;line-height:75px;height:75px;padding-left:15px;margin-bottom:35px}.blog-sidebar .sidebar-blog-features .blog:hover,.blog-sidebar .sidebar-blog-features a:hover{opacity:.3}@media screen and (max-width:768px){article.post .meta{background-size:120%}}.blog-column{width:66.6%}@media screen and (max-width:570px){.blog-column{width:100%}}.blog-sidebar{width:33.33333333%;padding-top:40px}.blog-sidebar img{display:block;margin-bottom:60px}.blog-sidebar .sidebar-blog-features{color:#121417;font-size:18px;line-height:22px}.blog-sidebar .sidebar-blog-features h1{font-size:19px;color:#d8127d;margin-bottom:0}.blog-sidebar .sidebar-blog-features time{font-size:18px;display:block;margin-bottom:5px}.blog-sidebar .sidebar-blog-features a{color:#000}.blog-sidebar .sidebar-blog-features .blog{margin-bottom:70px}@media screen and (max-width:570px){.blog-sidebar{width:50%;margin:0 auto}}.single-post .entry{color:#121417;font-size:18px;line-height:22px;width:80%}footer,footer a{font-size:14px;line-height:25px;color:#fff}.single-post .article-post{border-bottom:0}.page-template-template-companyblue .subtemplate:first-of-type .centered-content-padding{background-color:transparent}footer a{width:100%}footer a:hover{color:#fff}footer .bottom-footer,footer .bottom-footer a{color:#1e1e1e;font-size:13px;line-height:14px}footer .top-footer{background-color:#8c8c8c;padding:50px 0 40px}footer .top-footer ul{-webkit-columns:3;-moz-columns:3;columns:3;width:75%;float:left}footer .contact{width:25%;float:right}footer .bottom-footer{padding:20px 0 10px}footer .bottom-footer .menu{float:left;margin-left:15px}footer .bottom-footer .menu li{display:inline-block;border-left:1px solid #121417;padding:0 15px}footer .bottom-footer .menu li:nth-of-type(1){width:60px}footer .bottom-footer .menu li:nth-of-type(2){width:130px}footer .bottom-footer .social{float:right;position:relative;top:-2px}footer .bottom-footer .social li{display:inline-block}footer .copyright{float:left}footer .button{margin-bottom:10px}
\ No newline at end of file
diff --git a/assets/css/less/ascribe.less b/assets/css/less/ascribe.less
index 80fa3f0..6234037 100644
--- a/assets/css/less/ascribe.less
+++ b/assets/css/less/ascribe.less
@@ -26,6 +26,67 @@ header + .chevron-divider {
margin-top: 35px;
margin-left: 20px;
.tourNavText;
+
+ &:hover {
+ cursor: pointer;
+
+ a {
+ color: @pink;
+ }
+ ul {
+ &:before,
+ li a:after {
+ color: @pink;
+ }
+ }
+ }
+
+ ul {
+ display: flex;
+ flex-wrap: wrap;
+ padding: 0 35px;
+ position: relative;
+ -webkit-flex-direction: column;
+
+ &:hover {
+ cursor: pointer;
+ }
+
+ &.active {
+ li {
+ display: flex;
+ }
+ }
+ li {
+ flex-grow: 1;
+ order: 2;
+ display: none;
+
+ &.current-menu-item {
+ order: 1;
+ display: flex;
+
+ a {
+ position: relative;
+ &:after {
+ content: '▼';
+ display: inline-block;
+ position: absolute;
+ top: 3px;
+ right: -34px;
+ }
+ }
+ }
+ }
+ &:before {
+ content: 'for ';
+ display: inline-block;
+ position: absolute;
+ top: 0;
+ left: 0;
+ }
+
+ }
}
ul {
list-style: none;
@@ -188,6 +249,24 @@ header + .chevron-divider {
.ttl-columns.column-3;
padding-right: 100px;
}
+ .surround-circle {
+ .ttl-columns.column-3;
+ text-align: center;
+ position: relative;
+ width: 30%;
+ padding: 80px 50px 170px;
+
+ &:before {
+ top: 0;
+ left: 5%;
+ width: 90%;
+ background: transparent url('../img/circle.png') no-repeat center top;
+ background-size: 100%;
+ height: 100%;
+ content: '';
+ position: absolute;
+ }
+ }
img {
width: 105px;
display: block;
@@ -713,7 +792,8 @@ header + .chevron-divider {
float: right;
}
}
-.upcoming-events, .past-events {
+.upcoming-events,
+.past-events {
h2 {
text-align: center;
position:relative;
@@ -784,6 +864,45 @@ header + .chevron-divider {
.ttl-columns.column-3;
}
}
+.content-boxed {
+ background-color: @greyBg;
+
+ .centered-content-padding {
+ background-color: @greyBg;
+ }
+
+ .centered-content {
+ & > div {
+ border: 1px solid @pink;
+ background-color: @white;
+ padding: 30px;
+
+ & > ul {
+ margin: 30px;
+ overflow: hidden;
+
+ & > li {
+ float: left;
+ clear: left;
+ width: 100%;
+ text-align: right;
+ }
+ ul {
+ width: 70%;
+ float: right;
+ text-align: left;
+ }
+ }
+ }
+
+ p {
+ max-width: 640px;
+ }
+ img {
+ margin: 30px 0;
+ }
+ }
+}
// BLOG
.blog .column-container {
diff --git a/assets/js/ascribe.min.js b/assets/js/ascribe.min.js
index 4c2e628..ce72bf2 100644
--- a/assets/js/ascribe.min.js
+++ b/assets/js/ascribe.min.js
@@ -1,4 +1 @@
-/*! ascribe - v0.0.1
- * http://wordpress.org/themes
- * Copyright (c) 2015; * Licensed GPLv2+ */
-$(document).ready(function(){function a(){$(".case-study:gt(0)").addClass("hidden"),$(".slider-action").click(function(){var a=$(this).attr("id");"back"===a?($(".case-study").addClass("hidden"),$(".case-study").last().prependTo(".slide-container").removeClass("hidden")):(displayed=$(".case-study").first(),displayed.addClass("hidden"),$(".case-study").eq(1).removeClass("hidden"),displayed.appendTo(".slide-container"))})}function b(){jQuery("img.social-icon").each(function(){var a=jQuery(this),b=a.attr("id"),c=a.attr("class"),d=a.attr("src");jQuery.get(d,function(d){var e=jQuery(d).find("svg");"undefined"!=typeof b&&(e=e.attr("id",b)),"undefined"!=typeof c&&(e=e.attr("class",c+" replaced-svg")),e=e.removeAttr("xmlns:a"),a.replaceWith(e)},"xml")})}function c(){$(".featured-faqs dt").click(function(){$(this).next("dd").toggleClass("open")})}a(),b(),c()});
\ No newline at end of file
+$(document).ready(function(){slider();socialAsSvg();featuredFAQ();headerNavigation();function slider(){$(".case-study:gt(0)").addClass("hidden");$(".slider-action").click(function(){var direction=$(this).attr("id");if(direction==="back"){$(".case-study").addClass("hidden");$(".case-study").last().prependTo(".slide-container").removeClass("hidden")}else{displayed=$(".case-study").first();displayed.addClass("hidden");$(".case-study").eq(1).removeClass("hidden");displayed.appendTo(".slide-container")}})}function socialAsSvg(){jQuery("img.social-icon").each(function(){var $img=jQuery(this);var imgID=$img.attr("id");var imgClass=$img.attr("class");var imgURL=$img.attr("src");jQuery.get(imgURL,function(data){var $svg=jQuery(data).find("svg");if(typeof imgID!=="undefined"){$svg=$svg.attr("id",imgID)}if(typeof imgClass!=="undefined"){$svg=$svg.attr("class",imgClass+" replaced-svg")}$svg=$svg.removeAttr("xmlns:a");$img.replaceWith($svg)},"xml")})}function featuredFAQ(){$(".featured-faqs dt").click(function(){$(this).next("dd").toggleClass("open")})}function headerNavigation(){$(".current-menu-item").on("click",function(e){e.preventDefault()});$(".tour-switcher ul").on("click",function(e){if(false===$(this).hasClass("active")){e.preventDefault()}$(this).toggleClass("active")})}});
\ No newline at end of file
diff --git a/controller/classes/Subtemplate.php b/controller/classes/Subtemplate.php
index 4206692..7e7bc54 100644
--- a/controller/classes/Subtemplate.php
+++ b/controller/classes/Subtemplate.php
@@ -206,7 +206,7 @@ class Subtemplate {
while (have_rows('slides')) {
the_row();
- $content = get_sub_field('content');
+ $content = get_sub_field('content');
$image = get_sub_field('image')['url'];
$imageAlt = get_sub_field('image')['alt'];
@@ -219,7 +219,7 @@ class Subtemplate {
}
}
- $result = "";
+ $result = "";
return $result;
}
diff --git a/template-header.php b/template-header.php
index 6aad977..80c2f2d 100644
--- a/template-header.php
+++ b/template-header.php
@@ -5,6 +5,9 @@
* Date: 15-09-24
* Time: 5:32 PM
*/
+
+require 'controller/init.php';
+
?>
diff --git a/assets/img/circle.png b/assets/img/circle.png
new file mode 100644
index 0000000..b1b8afa
Binary files /dev/null and b/assets/img/circle.png differ
diff --git a/assets/js/ascribe.js b/assets/js/ascribe.js
index 88ddbca..20ae072 100644
--- a/assets/js/ascribe.js
+++ b/assets/js/ascribe.js
@@ -3,71 +3,87 @@
* Copyright (c) 2015; * Licensed GPLv2+ */
$(document).ready(function(){
- slider();
- socialAsSvg();
- featuredFAQ();
+ slider();
+ socialAsSvg();
+ featuredFAQ();
+ headerNavigation();
+ function slider() {
+ $('.case-study:gt(0)').addClass('hidden');
+ $('.slider-action').click(function(){
+ var direction = $(this).attr('id');
- function slider() {
- $('.case-study:gt(0)').addClass('hidden');
+ if (direction === 'back') {
+ $('.case-study').addClass('hidden');
+ $('.case-study').last().prependTo('.slide-container').removeClass('hidden');
+ }
+ else {
+ displayed = $('.case-study').first();
+ displayed.addClass('hidden');
+ $('.case-study').eq(1).removeClass('hidden');
+ displayed.appendTo('.slide-container');
+ }
- $('.slider-action').click(function(){
+ });
+ }
- var direction = $(this).attr('id');
+ function socialAsSvg() {
+ /*
+ * Replace all social icon images with inline SVG
+ */
+ jQuery('img.social-icon').each(function(){
+ var $img = jQuery(this);
+ var imgID = $img.attr('id');
+ var imgClass = $img.attr('class');
+ var imgURL = $img.attr('src');
- if (direction === 'back') {
- $('.case-study').addClass('hidden');
- $('.case-study').last().prependTo('.slide-container').removeClass('hidden');
- }
- else {
- displayed = $('.case-study').first();
- displayed.addClass('hidden');
- $('.case-study').eq(1).removeClass('hidden');
- displayed.appendTo('.slide-container');
- }
+ jQuery.get(imgURL, function(data) {
+ // Get the SVG tag, ignore the rest
+ var $svg = jQuery(data).find('svg');
- });
- }
- function socialAsSvg() {
- /*
- * Replace all social icon images with inline SVG
- */
- jQuery('img.social-icon').each(function(){
- var $img = jQuery(this);
- var imgID = $img.attr('id');
- var imgClass = $img.attr('class');
- var imgURL = $img.attr('src');
+ // Add replaced image's ID to the new SVG
+ if(typeof imgID !== 'undefined') {
+ $svg = $svg.attr('id', imgID);
+ }
+ // Add replaced image's classes to the new SVG
+ if(typeof imgClass !== 'undefined') {
+ $svg = $svg.attr('class', imgClass+' replaced-svg');
+ }
- jQuery.get(imgURL, function(data) {
- // Get the SVG tag, ignore the rest
- var $svg = jQuery(data).find('svg');
+ // Remove any invalid XML tags as per http://validator.w3.org
+ $svg = $svg.removeAttr('xmlns:a');
- // Add replaced image's ID to the new SVG
- if(typeof imgID !== 'undefined') {
- $svg = $svg.attr('id', imgID);
- }
- // Add replaced image's classes to the new SVG
- if(typeof imgClass !== 'undefined') {
- $svg = $svg.attr('class', imgClass+' replaced-svg');
- }
+ // Replace image with new SVG
+ $img.replaceWith($svg);
- // Remove any invalid XML tags as per http://validator.w3.org
- $svg = $svg.removeAttr('xmlns:a');
+ }, 'xml');
- // Replace image with new SVG
- $img.replaceWith($svg);
+ });
+ }
- }, 'xml');
+ function featuredFAQ() {
+ $('.featured-faqs dt').click(function() {
+ $(this).next('dd').toggleClass('open');
+ });
+ }
- });
- }
- function featuredFAQ() {
- $('.featured-faqs dt').click(function() {
- $(this).next('dd').toggleClass('open');
- });
- }
+ function headerNavigation() {
+ $('.current-menu-item').on( 'click', function(e) {
+ e.preventDefault();
+ });
+
+ $('.tour-switcher ul').on( 'click', function(e) {
+
+ // OPEN SWITCHER
+ if ( false === $(this).hasClass('active') ) {
+ e.preventDefault();
+ }
+
+ $(this).toggleClass('active');
+ });
+ }
});